@@ -18,10 +18,12 @@ CONFIG_HEADER_FIELDS = 'structure.headers'
 CONFIG_TAXONOMY_LIST = 'taxonomy.options'
 CONFIG_TAXONOMY_ID = 'taxonomy.id'
 CONFIG_TAXONOMY_CT = 'taxonomy.columnTypes'
+CONFIG_TAXONOMY_SETTINGS = 'taxonomy.settings'
 
 CONFIG_CONSTANTS = 'constants'
 
 CONFIG_MODEL_MAPPING = 'model.mapping'
 CONFIG_MODEL_EXTRA_FIELDS = 'model.extraFields'
+CONFIG_PRIMARY_KEY = 'model.primary_key'
 
 CONFIG_PUBLISH_ALLOWED = 'publish.allowed'
